@@ -115,6 +115,12 @@ def checkPathSpec(value, arg_name, allow_disable):
             % (arg_name, old, value)
         )
 
+    if "\n" in value or "\r" in value:
+        Tracing.options_logger.sysexit(
+            "Using a new line in value '%s=%r' value is not allowed."
+            % (arg_name, value)
+        )
+
     if "{NONE}" in value:
         if not allow_disable:
             Tracing.options_logger.sysexit(
@@ -1067,6 +1073,7 @@ make sure that is intended."""
         and not shallMakeModule()
         and not shallUseStaticLibPython()
         and getSystemStaticLibPythonPath() is not None
+        and not shallUsePythonDebug()
     ):
         Tracing.options_logger.info(
             """Detected static libpython to exist, consider '--static-libpython=yes' for better performance, \
