@@ -1,20 +1,6 @@
-#     Copyright 2023, Kay Hayen, mailto:kay.hayen@gmail.com
-#
-#     Part of "Nuitka", an optimizing Python compiler that is compatible and
-#     integrates with CPython, but also works on its own.
-#
-#     Licensed under the Apache License, Version 2.0 (the "License");
-#     you may not use this file except in compliance with the License.
-#     You may obtain a copy of the License at
-#
-#        http://www.apache.org/licenses/LICENSE-2.0
-#
-#     Unless required by applicable law or agreed to in writing, software
-#     distributed under the License is distributed on an "AS IS" BASIS,
-#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#     See the License for the specific language governing permissions and
-#     limitations under the License.
-#
+#     Copyright 2024, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+
+
 """ Codes for operations.
 
 There are unary and binary operations. Many of them have specializations and
@@ -243,10 +229,7 @@ def _getBinaryOperationCode(
         if left.isExpressionVariableRef() and left.getVariable().isModuleVariable():
             emit("%s = %s;" % (context.getInplaceLeftName(), left_name))
 
-        if (
-            not left.isExpressionVariableRef()
-            and not left.isExpressionTempVariableRef()
-        ):
+        if not left.isExpressionVariableRefOrTempVariableRef():
             if not context.needsCleanup(left_name):
                 getTakeReferenceCode(left_name, emit)
 
@@ -262,10 +245,7 @@ def _getBinaryOperationCode(
 
         emit("%s = %s;" % (to_name, left_name))
 
-        if (
-            not left.isExpressionVariableRef()
-            and not left.isExpressionTempVariableRef()
-        ):
+        if not left.isExpressionVariableRefOrTempVariableRef():
             context.addCleanupTempName(to_name)
     else:
         if needs_argument_swap:
@@ -348,7 +328,6 @@ def _getUnaryOperationCode(
     with withObjectCodeTemporaryAssignment(
         to_name, "op_%s_res" % operator.lower(), expression, emit, context
     ) as value_name:
-
         emit(
             "%s = %s(%s);"
             % (
@@ -368,3 +347,19 @@ def _getUnaryOperationCode(
 
         if ref_count:
             context.addCleanupTempName(value_name)
+
+
+#     Part of "Nuitka", an optimizing Python compiler that is compatible and
+#     integrates with CPython, but also works on its own.
+#
+#     Licensed under the Apache License, Version 2.0 (the "License");
+#     you may not use this file except in compliance with the License.
+#     You may obtain a copy of the License at
+#
+#        http://www.apache.org/licenses/LICENSE-2.0
+#
+#     Unless required by applicable law or agreed to in writing, software
+#     distributed under the License is distributed on an "AS IS" BASIS,
+#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#     See the License for the specific language governing permissions and
+#     limitations under the License.
