@@ -1,20 +1,6 @@
-#     Copyright 2023, Kay Hayen, mailto:kay.hayen@gmail.com
-#
-#     Part of "Nuitka", an optimizing Python compiler that is compatible and
-#     integrates with CPython, but also works on its own.
-#
-#     Licensed under the Apache License, Version 2.0 (the "License");
-#     you may not use this file except in compliance with the License.
-#     You may obtain a copy of the License at
-#
-#        http://www.apache.org/licenses/LICENSE-2.0
-#
-#     Unless required by applicable law or agreed to in writing, software
-#     distributed under the License is distributed on an "AS IS" BASIS,
-#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#     See the License for the specific language governing permissions and
-#     limitations under the License.
-#
+#     Copyright 2024, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+
+
 """ Subscript related code generation.
 
 There is special handling for integer indexes, which can be dealt with
@@ -131,7 +117,6 @@ def generateSubscriptLookupCode(to_name, expression, emit, context):
     with withObjectCodeTemporaryAssignment(
         to_name, "subscript_result", expression, emit, context
     ) as value_name:
-
         if integer_subscript:
             _getIntegerSubscriptLookupCode(
                 to_name=value_name,
@@ -169,12 +154,13 @@ def generateSubscriptCheckCode(to_name, expression, emit, context):
 
     if integer_subscript:
         emit(
-            "%s = HAS_SUBSCRIPT_CONST(%s, %s, %s);"
+            "%s = HAS_SUBSCRIPT_CONST(tstate, %s, %s, %s);"
             % (res_name, subscribed_name, subscript_name, subscript_constant)
         )
     else:
         emit(
-            "%s = HAS_SUBSCRIPT(%s, %s);" % (res_name, subscribed_name, subscript_name)
+            "%s = HAS_SUBSCRIPT(tstate, %s, %s);"
+            % (res_name, subscribed_name, subscript_name)
         )
 
     getReleaseCodes((subscript_name, subscribed_name), emit, context)
@@ -190,7 +176,7 @@ def _getIntegerSubscriptLookupCode(
     to_name, subscribed_name, subscript_name, subscript_value, emit, context
 ):
     emit(
-        "%s = LOOKUP_SUBSCRIPT_CONST(%s, %s, %s);"
+        "%s = LOOKUP_SUBSCRIPT_CONST(tstate, %s, %s, %s);"
         % (to_name, subscribed_name, subscript_name, subscript_value)
     )
 
@@ -205,7 +191,10 @@ def _getIntegerSubscriptLookupCode(
 
 
 def _getSubscriptLookupCode(to_name, subscript_name, subscribed_name, emit, context):
-    emit("%s = LOOKUP_SUBSCRIPT(%s, %s);" % (to_name, subscribed_name, subscript_name))
+    emit(
+        "%s = LOOKUP_SUBSCRIPT(tstate, %s, %s);"
+        % (to_name, subscribed_name, subscript_name)
+    )
 
     getErrorExitCode(
         check_name=to_name,
@@ -225,7 +214,7 @@ def _getIntegerSubscriptAssignmentCode(
     res_name = context.allocateTempName("ass_subscript_res", "int")
 
     emit(
-        "%s = SET_SUBSCRIPT_CONST(%s, %s, %s, %s);"
+        "%s = SET_SUBSCRIPT_CONST(tstate, %s, %s, %s, %s);"
         % (res_name, subscribed_name, subscript_name, subscript_value, value_name)
     )
 
@@ -241,7 +230,7 @@ def _getSubscriptAssignmentCode(target_name, subscript_name, value_name, emit, c
     res_name = context.getBoolResName()
 
     emit(
-        "%s = SET_SUBSCRIPT(%s, %s, %s);"
+        "%s = SET_SUBSCRIPT(tstate, %s, %s, %s);"
         % (res_name, target_name, subscript_name, value_name)
     )
 
@@ -264,3 +253,19 @@ def _getSubscriptDelCode(target_name, subscript_name, emit, context):
         emit=emit,
         context=context,
     )
+
+
+#     Part of "Nuitka", an optimizing Python compiler that is compatible and
+#     integrates with CPython, but also works on its own.
+#
+#     Licensed under the Apache License, Version 2.0 (the "License");
+#     you may not use this file except in compliance with the License.
+#     You may obtain a copy of the License at
+#
+#        http://www.apache.org/licenses/LICENSE-2.0
+#
+#     Unless required by applicable law or agreed to in writing, software
+#     distributed under the License is distributed on an "AS IS" BASIS,
+#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#     See the License for the specific language governing permissions and
+#     limitations under the License.
