@@ -1,20 +1,6 @@
-#     Copyright 2023, Kay Hayen, mailto:kay.hayen@gmail.com
-#
-#     Part of "Nuitka", an optimizing Python compiler that is compatible and
-#     integrates with CPython, but also works on its own.
-#
-#     Licensed under the Apache License, Version 2.0 (the "License");
-#     you may not use this file except in compliance with the License.
-#     You may obtain a copy of the License at
-#
-#        http://www.apache.org/licenses/LICENSE-2.0
-#
-#     Unless required by applicable law or agreed to in writing, software
-#     distributed under the License is distributed on an "AS IS" BASIS,
-#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#     See the License for the specific language governing permissions and
-#     limitations under the License.
-#
+#     Copyright 2024, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+
+
 """ Optimize calls to built-in references to specific built-in calls.
 
 For built-in name references, we check if it's one of the supported built-in
@@ -882,7 +868,7 @@ def eval_extractor(node):
         )
 
         source_variable = outline_body.allocateTempVariable(
-            temp_scope=None, name="source"
+            temp_scope=None, name="source", temp_type="object"
         )
 
         final.setChildStatements(
@@ -1012,7 +998,7 @@ if python_version >= 0x300:
 
     def exec_extractor(node):
         def wrapExpressionBuiltinExecCreation(
-            source, globals_arg, locals_arg, source_ref
+            source, globals_arg, locals_arg, closure=None, source_ref=None
         ):
             provider = node.getParentVariableProvider()
 
@@ -1036,6 +1022,7 @@ if python_version >= 0x300:
                             source_code=source,
                             globals_arg=globals_ref,
                             locals_arg=locals_ref,
+                            closure=closure,
                             source_ref=source_ref,
                         ),
                         source_ref=source_ref,
@@ -1064,7 +1051,7 @@ if python_version >= 0x300:
         return BuiltinParameterSpecs.extractBuiltinArgs(
             node=node,
             builtin_class=wrapExpressionBuiltinExecCreation,
-            builtin_spec=BuiltinParameterSpecs.builtin_eval_spec,
+            builtin_spec=BuiltinParameterSpecs.builtin_exec_spec,
         )
 
 
@@ -1575,3 +1562,19 @@ def computeBuiltinCall(builtin_name, call_node):
         #     )
 
         return call_node, None, None
+
+
+#     Part of "Nuitka", an optimizing Python compiler that is compatible and
+#     integrates with CPython, but also works on its own.
+#
+#     Licensed under the Apache License, Version 2.0 (the "License");
+#     you may not use this file except in compliance with the License.
+#     You may obtain a copy of the License at
+#
+#        http://www.apache.org/licenses/LICENSE-2.0
+#
+#     Unless required by applicable law or agreed to in writing, software
+#     distributed under the License is distributed on an "AS IS" BASIS,
+#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#     See the License for the specific language governing permissions and
+#     limitations under the License.
