@@ -1,23 +1,6 @@
 #!/usr/bin/env python
-#     Copyright 2023, Kay Hayen, mailto:kay.hayen@gmail.com
-#
-#     Python test originally created or extracted from other peoples work. The
-#     parts from me are licensed as below. It is at least Free Software where
-#     it's copied from other people. In these cases, that will normally be
-#     indicated.
-#
-#     Licensed under the Apache License, Version 2.0 (the "License");
-#     you may not use this file except in compliance with the License.
-#     You may obtain a copy of the License at
-#
-#         http://www.apache.org/licenses/LICENSE-2.0
-#
-#     Unless required by applicable law or agreed to in writing, software
-#     distributed under the License is distributed on an "AS IS" BASIS,
-#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#     See the License for the specific language governing permissions and
-#     limitations under the License.
-#
+#     Copyright 2024, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+
 
 """ Runner for standalone program tests of Nuitka.
 
@@ -234,6 +217,10 @@ def main():
             if filename != "PySide6":
                 extra_flags.append("ignore_warnings")
 
+        if filename.startswith("PyQt6") and isMacOS():
+            reportSkip("not currently supported", ".", filename)
+            continue
+
         test_logger.info(
             "Consider output of standalone mode compiled program: %s" % filename
         )
@@ -295,3 +282,20 @@ def main():
 
 if __name__ == "__main__":
     main()
+
+#     Python test originally created or extracted from other peoples work. The
+#     parts from me are licensed as below. It is at least Free Software where
+#     it's copied from other people. In these cases, that will normally be
+#     indicated.
+#
+#     Licensed under the Apache License, Version 2.0 (the "License");
+#     you may not use this file except in compliance with the License.
+#     You may obtain a copy of the License at
+#
+#         http://www.apache.org/licenses/LICENSE-2.0
+#
+#     Unless required by applicable law or agreed to in writing, software
+#     distributed under the License is distributed on an "AS IS" BASIS,
+#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#     See the License for the specific language governing permissions and
+#     limitations under the License.
